==> haskell-bifunctors-5.4.2-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bifunctors
version: 5.4.2
id: bifunctors-5.4.2-8sihn7PNvccAEMEjqQmBaw
key: bifunctors-5.4.2-8sihn7PNvccAEMEjqQmBaw
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/bifunctors/
synopsis: Bifunctors
description:
    Bifunctors
category: Data, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biff Data.Bifunctor.Clown
    Data.Bifunctor.Fix Data.Bifunctor.Flip Data.Bifunctor.Functor
    Data.Bifunctor.Join Data.Bifunctor.Joker Data.Bifunctor.Product
    Data.Bifunctor.Sum Data.Bifunctor.Tannen Data.Bifunctor.TH
    Data.Bifunctor.Wrapped Data.Bifoldable Data.Bitraversable
hidden-modules: Data.Bifunctor.TH.Internal Paths_bifunctors
abi: d9b27e148a2cfcf4e714909c3096c632
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/bifunctors-5.4.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/bifunctors-5.4.2
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/bifunctors-5.4.2
hs-libraries: HSbifunctors-5.4.2-8sihn7PNvccAEMEjqQmBaw
depends:
    base-4.9.1.0 base-orphans-0.6-AbJ3lKVXygDCG0eeQEv8Iu
    comonad-5.0.1-57iqRHH7ifDe0jWuqpsGW containers-0.5.7.1
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai template-haskell-2.11.1.0
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
haddock-interfaces: /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html: /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bifunctors-5.4.2-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bifunctors
version: 5.4.2
id: bifunctors-5.4.2-Hs7FNb9nROsIXkBtaUQIi2
key: bifunctors-5.4.2-Hs7FNb9nROsIXkBtaUQIi2
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/bifunctors/
synopsis: Bifunctors
description:
    Bifunctors
category: Data, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biff Data.Bifunctor.Clown
    Data.Bifunctor.Fix Data.Bifunctor.Flip Data.Bifunctor.Functor
    Data.Bifunctor.Join Data.Bifunctor.Joker Data.Bifunctor.Product
    Data.Bifunctor.Sum Data.Bifunctor.Tannen Data.Bifunctor.TH
    Data.Bifunctor.Wrapped Data.Bifoldable Data.Bitraversable
hidden-modules: Data.Bifunctor.TH.Internal Paths_bifunctors
abi: d870e81c2674bd9c12868daeb87ad869
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/bifunctors-5.4.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/bifunctors-5.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/bifunctors-5.4.2
hs-libraries: HSbifunctors-5.4.2-Hs7FNb9nROsIXkBtaUQIi2
depends:
    base-4.9.1.0 base-orphans-0.6-AbJ3lKVXygDCG0eeQEv8Iu
    comonad-5.0.2-3DxYbKldXlbDmwZMty0nml containers-0.5.7.1
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai template-haskell-2.11.1.0
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
haddock-interfaces: /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html: /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
